#
# spec file for package ssldump
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ssldump
Version:        1.9
Release:        1.2
Summary:        SSLv3/TLS Network Protocol Analyzer
License:        BSD-3-Clause
Group:          Productivity/Networking/Diagnostic
URL:            https://adulau.github.io/ssldump/
#Git-Clone:     https://github.com/adulau/ssldump.git
Source:         https://github.com/adulau/ssldump/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  libnet-devel
BuildRequires:  libtool
BuildRequires:  ninja
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(json-c)
%if 0%{?suse_version} > 1320 || (0%{?is_opensuse} && 0%{?leap_version} == 420300)
BuildRequires:  libpcap-devel-static
%else
BuildRequires:  libpcap-devel
%endif

%description
ssldump is an SSLv3/TLS network protocol analyzer. It identifies TCP
connections on the chosen network interface and attempts to interpret
them as SSLv3/TLS traffic. When it identifies SSLv3/TLS traffic, it
decodes the records and outputs them in a textual form to stdout. If
provided with the appropriate keying material, it also decrypts the
connections and displays the application data traffic.

%prep
%autosetup

%build
cmake -G Ninja -B build
ninja -C build

%install
# Binaries
install -D -m 0755 build/%{name} %{buildroot}%{_sbindir}/%{name}
# Manpages
install -d %{buildroot}/%{_mandir}/man1
install -m 0644 ssldump.1* %{buildroot}/%{_mandir}/man1

%files
%license COPYRIGHT
%doc ChangeLog NEWS README.md
%{_sbindir}/ssldump
%{_mandir}/man1/ssldump.1%{?ext_man}

%changelog
* Sun Nov  3 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.9
  Enhancements
  * Original PCAP Timestamps: Added support for original PCAP
    timestamps, replacing timeofday-generated timestamps for
    improved accuracy.
  * TLS 1.3 Handling: Introduced handling for TLS version 1.3.
  * RAW IP Capture Support: Implemented support for "raw IP"
    captures, allowing capture of packets without Layer 2 headers.
  * Connection Tracker Enhancements: Improved connection tracking
    with live list and purge functionality.
  Bug Fixes
  * Documentation Updates: Updated README layout and fixed command
    documentation.
* Fri Oct 13 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.8:
  * Add date to version output
  * Print meaningful error messages
  * use cmake as build tool
  * Add -z option for printing timestamps in front of TCP headers
- Update to version 1.7:
  * For Y2K38 on 32 bit systems time_t tv_sec can be long long
  * Adding tls1.3 decryption support
* Sun Feb  5 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.6
  Changes:
  * Fix missing port # in pcap files
  * Print MAC keys only for non AEAD ciphers
* Thu May 26 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5
  Changes
  * doc: An example use-case of JA3.
  Other
  * Add parentheses around MAX and MIN.
  * Add support for pcap output to FIFO.
* Mon Apr 12 2021 Martin Hauke <mardnh@gmx.de>
- Specfile overhaul
- Update source URL (original upstream is dead)
- Update to version 1.4
  * Add support for IPv6 traffic dump
  * Fix ja3(s) length of strings used in MD5 computation + update
    MD5 functions.
  * Add support for ja3 & ja3s.
- Update to version 1.3
  * Avoid leak in TCP segment reassembly code.
  * Avoid client session_id related leak.
  * Avoid server_random related leak.
  * Avoid client_random related leak.
  * Check ssl_decode_enum() return code correctly.
  * Exit process_tcp_packet() in case TCP header is incomplete.
  * Check timestamp_diff return code correctly.
  * Cleanup before exit on error.
  * Fix for crash if length of captured frame is less than
    Ethernet header size.
  * Check packet size before looking at IP header.
  * Check return code after string extraction.
  * Limit length during server name decoding.
  * Decode ClientHello v2 properly.
  * Output error to stderr.
  * Avoid leak by freeing SSL decoding context properly.
  * Close everything properly in case of SIGINT.
  * Fix leak in associative array implementation.
  * First import of the JSON output code
  * Do not print information message when no connection is
    cleaned at shutdown.
  * Fix memory leak in ssl_process_server_session_id()
  * Close global pcap struct properly in case of SIGINT.
  * Add missing extension names
  * Code cleanup
  * Add save decrypted datato pcap. first alpha version.
  * Fix for use of deprecated OpenSSL HMAC functions.
  * Fix for type casting related warnings.
  * Add missing function prototype.
  * Remove definitions of unused variables.
  * Fix for uninitialized variables and possible overflow.
  * Remove unused RCSSTRING variable globally.
- Drop patches (not longer needed)
  * ssldump-0.9b3-libpcap.diff
  * random_return.patch
  * ssldump-0.9b3-aes.patch
  * implicit_def.patch
  * ssldump-0.9b3-newssl.patch
  * ssldump-cvs-06-19-2006.diff
  * update-config.patch
* Tue Mar 24 2020 Michael Calmer <mc@suse.com>
- fix macro to fix build on openSUSE Leap 15.2
* Thu Jun 29 2017 mlin@suse.com
- Compile with libpcap-devel-static if Leap
  * Since pcap updated to new version in 42.3 too, ssldump need to
    compile with libpcap-devel-static.
* Fri Jul  3 2015 alarrosa@suse.com
- Added a conditional build requirement to compile in versions
  other than Factory.
* Fri Jul  3 2015 dimstar@opensuse.org
- BuildRequires libpcap-devel-static instead of libpcap: the static
  library has been split out.
* Sun Jan 29 2012 coolo@suse.com
- update config.* files - upstream is dead ;(
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Jul 26 2007 prusnak@suse.cz
- changed libpcap to libpcap-devel in BuildRequires
* Tue Jun  5 2007 mc@suse.de
- add ssldump-cvs-06-19-2006.diff
- re-work patch for new ssl version
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Oct 14 2005 ro@suse.de
- include openssl/md5.h in ssldecode.c
* Wed Jul  6 2005 choeger@suse.de
- #include <string.h> when using related functions
* Thu Feb 17 2005 choeger@suse.de
- Bugfix Bugzilla ID#50952 - ssldump has no support for AES cipher-suites
* Fri Apr 23 2004 choeger@suse.de
- use -fno-strict-aliasing to compile
- fixed two functions which does not return anything matching
  their prototypes
* Thu Feb 12 2004 ro@suse.de
- adapt to change in libpcap: include moved to pcap_bpf.h
* Mon Nov  3 2003 choeger@suse.de
- make it build on biarch platforms
* Fri Oct 31 2003 choeger@suse.de
- new package (v0.9b3)
